Index: pbx/pbx_lua.c
===================================================================
--- pbx/pbx_lua.c	(revision 89168)
+++ pbx/pbx_lua.c	(working copy)
@@ -868,9 +868,9 @@
  * \brief Load the extensions.lua file from the internal buffer
  *
  * \param L the lua_State to use
+ * \param chan channel to work on
  *
  * This function also sets up some constructs used by the extensions.lua file.
- *
  * In the event of an error, an error string will be pushed onto the lua stack.
  *
  * \retval 0 success
Index: channels/chan_unistim.c
===================================================================
--- channels/chan_unistim.c	(revision 89168)
+++ channels/chan_unistim.c	(working copy)
@@ -385,7 +385,7 @@
 	ast_mutex_t lock;
 	/*! Like 200 */
 	char name[80];
-	/*! Like USTM/200@black */
+	/*! Like USTM/200\@black */
 	char fullname[80];
 	/*! pointer to our current connection, channel... */
 	struct unistim_subchannel *subs[MAX_SUBS];
Index: include/asterisk/cli.h
===================================================================
--- include/asterisk/cli.h	(revision 89168)
+++ include/asterisk/cli.h	(working copy)
@@ -220,6 +220,8 @@
 /*! 
  * \brief Interprets a command
  * Interpret a command s, sending output to fd
+ * \param fd pipe
+ * \param s incoming string
  * \retval 0 on success
  * \retval -1 on failure
  */
@@ -227,14 +229,16 @@
 
 /*! 
  * \brief Executes multiple CLI commands
- * Interpret strings separated by '\0' and execute each one, sending output to fd
+ * Interpret strings separated by NULL and execute each one, sending output to fd
+ * \param fd pipe
  * \param size is the total size of the string
+ * \param s incoming string
  * \retval number of commands executed
  */
 int ast_cli_command_multiple(int fd, size_t size, const char *s);
 
 /*! \brief Registers a command or an array of commands
- * \param e which cli entry to register
+ * \param e which cli entry to register.
  * Register your own command
  * \retval 0 on success
  * \retval -1 on failure
@@ -252,7 +256,7 @@
  * \brief Unregisters a command or an array of commands
  * \param e which cli entry to unregister
  * Unregister your own command.  You must pass a completed ast_cli_entry structure
- * \return 0.
+ * \return 0
  */
 int ast_cli_unregister(struct ast_cli_entry *e);
 
@@ -280,14 +284,14 @@
  *
  * The first entry (offset 0) of the result is the longest common substring
  * in the results, useful to extend the string that has been completed.
- * Subsequent entries are all possible values, followe by a NULL.
+ * Subsequent entries are all possible values, followed by a NULL.
  * All strings and the array itself are malloc'ed and must be freed
  * by the caller.
  */
 char **ast_cli_completion_matches(const char *, const char *);
 
 /*!
- * \brief Command completion for the list of active channels
+ * \brief Command completion for the list of active channels.
  *
  * This can be called from a CLI command completion function that wants to
  * complete from the list of active channels.  'rpos' is the required
Index: include/asterisk/pbx.h
===================================================================
--- include/asterisk/pbx.h	(revision 89168)
+++ include/asterisk/pbx.h	(working copy)
@@ -529,6 +529,8 @@
  * \param exten new extension to add
  * \param priority priority of new extension
  * \param callerid callerid of extension
+ * \param found
+ * \param combined_find_spawn 
  *
  * This adds a new extension to the asterisk extension list.
  *
Index: main/ast_expr2f.c
===================================================================
--- main/ast_expr2f.c	(revision 89168)
+++ main/ast_expr2f.c	(working copy)
@@ -2774,7 +2774,7 @@
 
 /** Setup the input buffer state to scan a string. The next call to ast_yylex() will
  * scan from a @e copy of @a str.
- * @param str a NUL-terminated string to scan
+ * @param yy_str a NUL-terminated string to scan
  * @param yyscanner The scanner object.
  * @return the newly allocated buffer state object.
  * @note If you want to scan bytes that may contain NUL values, then use
@@ -2950,7 +2950,7 @@
 }
 
 /** Set the current column.
- * @param line_number
+ * @param column_no
  * @param yyscanner The scanner object.
  */
 void ast_yyset_column (int  column_no , yyscan_t yyscanner)
Index: res/res_config_sqlite.c
===================================================================
--- res/res_config_sqlite.c	(revision 89168)
+++ res/res_config_sqlite.c	(working copy)
@@ -448,9 +448,9 @@
 /*!
  * \brief Asterisk callback function for the CLI status command.
  *
- * \param fd file descriptor provided by Asterisk to use with ast_cli()
- * \param argc number of arguments
- * \param argv arguments list
+ * \param e CLI command
+ * \param cmd 
+ * \param a CLI argument list
  * \return RESULT_SUCCESS
  */
 static char *handle_cli_show_sqlite_status(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a);
Index: res/res_crypto.c
===================================================================
--- res/res_crypto.c	(revision 89168)
+++ res/res_crypto.c	(working copy)
@@ -494,9 +494,9 @@
 
 /*! 
  * \brief show the list of RSA keys 
- * \param fd file descriptor
- * \param argc no of arguements
- * \param argv list of arguements
+ * \param e CLI command
+ * \param cmd
+ * \param a list of CLI arguements
  * \return RESULT_SUCCESS
 */
 static char *handle_cli_keys_show(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
@@ -540,9 +540,9 @@
 
 /*! 
  * \brief initialize all RSA keys  
- * \param fd file descriptor
- * \param argc no of arguements
- * \param argv list of arguements
+ * \param e CLI command
+ * \param cmd 
+ * \param a list of CLI arguements
  * \return RESULT_SUCCESS
 */
 static char *handle_cli_keys_init(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
Index: res/res_convert.c
===================================================================
--- res/res_convert.c	(revision 89168)
+++ res/res_convert.c	(working copy)
@@ -58,9 +58,9 @@
 
 /*! 
  * \brief Convert a file from one format to another 
- * \param fd file descriptor
- * \param argc no arguements
- * \param argv list of arguements
+ * \param e CLI entry
+ * \param cmd command number
+ * \param a list of cli arguements
  * \retval CLI_SUCCESS on success.
  * \retval CLI_SHOWUSAGE or CLI_FAILURE on failure.
 */
